diff --git a/db_create.php b/db_create.php
index d3e5062414..0dff8e4553 100644
--- a/db_create.php
+++ b/db_create.php
@@ -85,7 +85,7 @@ if (! $result) {
* @global array $GLOBALS['extra_data']
* @name $extra_data
*/
- $extra_data['sql_query'] = PMA_showMessage(null, $sql_query, 'success');
+ $extra_data['sql_query'] = PMA_getMessage(null, $sql_query, 'success');
//Construct the html for the new database, so that it can be appended to
// the list of databases on server_databases.php
diff --git a/db_operations.php b/db_operations.php
index 427a102ea0..5a04bde59c 100644
--- a/db_operations.php
+++ b/db_operations.php
@@ -341,7 +341,7 @@ if (strlen($db) && (! empty($db_rename) || ! empty($db_copy))) {
*/
if ( $GLOBALS['is_ajax_request'] == true) {
$extra_data['newname'] = $newname;
- $extra_data['sql_query'] = PMA_showMessage(null, $sql_query);
+ $extra_data['sql_query'] = PMA_getMessage(null, $sql_query);
PMA_ajaxResponse($message, $message->isSuccess(), $extra_data);
};
}
@@ -375,7 +375,7 @@ if (empty($is_info)) {
echo "\n";
if (isset($message)) {
- PMA_showMessage($message, $sql_query);
+ echo PMA_getMessage($message, $sql_query);
unset($message);
}
}
diff --git a/db_tracking.php b/db_tracking.php
index 4077f75748..e151977baf 100644
--- a/db_tracking.php
+++ b/db_tracking.php
@@ -225,7 +225,7 @@ if (count($data['ddlog']) > 0) {
foreach ($data['ddlog'] as $entry) {
$log .= '# ' . $entry['date'] . ' ' . $entry['username'] . "\n" . $entry['statement'] . "\n";
}
- PMA_showMessage(__('Database Log'), $log);
+ echo PMA_getMessage(__('Database Log'), $log);
}
/**
diff --git a/js/db_operations.js b/js/db_operations.js
index c9c0289232..170ff1ec0e 100644
--- a/js/db_operations.js
+++ b/js/db_operations.js
@@ -60,7 +60,7 @@ $(function() {
.end()
.after(data.sql_query);
- //Remove the empty notice div generated due to a NULL query passed to PMA_showMessage()
+ //Remove the empty notice div generated due to a NULL query passed to PMA_getMessage()
var $notice_class = $("#floating_menubar").next("div").find('.notice');
if ($notice_class.text() == '') {
$notice_class.remove();
diff --git a/js/server_privileges.js b/js/server_privileges.js
index 050ec45d79..fa2cc53119 100644
--- a/js/server_privileges.js
+++ b/js/server_privileges.js
@@ -188,7 +188,7 @@ $(function() {
.end()
.after(data.sql_query);
- //Remove the empty notice div generated due to a NULL query passed to PMA_showMessage()
+ //Remove the empty notice div generated due to a NULL query passed to PMA_getMessage()
var $notice_class = $("#floating_menubar").next("div").find('.notice');
if ($notice_class.text() == '') {
$notice_class.remove();
diff --git a/js/tbl_change.js b/js/tbl_change.js
index 05132d3664..04c5247fac 100644
--- a/js/tbl_change.js
+++ b/js/tbl_change.js
@@ -345,7 +345,7 @@ $(function() {
.end()
.after(data.sql_query);
- //Remove the empty notice div generated due to a NULL query passed to PMA_showMessage()
+ //Remove the empty notice div generated due to a NULL query passed to PMA_getMessage()
var $notice_class = $("#floating_menubar").next("div").find('.notice');
if ($notice_class.text() == '') {
$notice_class.remove();
diff --git a/libraries/Menu.class.php b/libraries/Menu.class.php
index 3e00bbf4e6..60fdbd0c8f 100644
--- a/libraries/Menu.class.php
+++ b/libraries/Menu.class.php
@@ -89,7 +89,7 @@ class PMA_Menu
echo $this->_getBreadcrumbs();
echo $this->_getMenu();
if (! empty($GLOBALS['message'])) {
- PMA_showMessage($GLOBALS['message']);
+ echo PMA_getMessage($GLOBALS['message']);
unset($GLOBALS['message']);
}
}
diff --git a/libraries/display_tbl.lib.php b/libraries/display_tbl.lib.php
index 10806345c0..3b12c07a53 100644
--- a/libraries/display_tbl.lib.php
+++ b/libraries/display_tbl.lib.php
@@ -51,7 +51,7 @@ require_once './libraries/Index.class.php';
*
* @access private
*
- * @see PMA_displayTable()
+ * @see PMA_getTable()
*/
function PMA_setDisplayMode(&$the_disp_mode, &$the_total)
{
@@ -218,7 +218,7 @@ function PMA_isSelect()
/**
- * Displays a navigation button
+ * Get a navigation button
*
* @param string $caption iconic caption for button
* @param string $title text for button
@@ -228,7 +228,7 @@ function PMA_isSelect()
* @param string $input_for_real_end optional hidden field for special treatment
* @param string $onclick optional onclick clause
*
- * @return void
+ * @return string html content
*
* @global string $db the database name
* @global string $table the table name
@@ -236,9 +236,9 @@ function PMA_isSelect()
*
* @access private
*
- * @see PMA_displayTableNavigation()
+ * @see PMA_getTableNavigation()
*/
-function PMA_displayTableNavigationButton($caption, $title, $pos, $html_sql_query,
+function PMA_getTableNavigationButton($caption, $title, $pos, $html_sql_query,
$onsubmit = '', $input_for_real_end = '', $onclick = ''
) {
global $db, $table, $goto;
@@ -254,34 +254,32 @@ function PMA_displayTableNavigationButton($caption, $title, $pos, $html_sql_quer
) {
$caption_output .= ' ' . $title;
}
- $title_output = ' title="' . $title . '"';
- ?>
-
-
-
-'
+ . ''
+ . '';
+
+} // end function PMA_getTableNavigationButton()
/**
- * Displays a navigation bar to browse among the results of a SQL query
+ * Get a navigation bar to browse among the results of a SQL query
*
* @param integer $pos_next the offset for the "next" page
* @param integer $pos_prev the offset for the "previous" page
* @param string $sql_query the URL-encoded query
* @param string $id_for_direction_dropdown the id for the direction dropdown
*
- * @return void
+ * @return string html content
*
* @global string $db the database name
* @global string $table the table name
@@ -295,15 +293,17 @@ function PMA_displayTableNavigationButton($caption, $title, $pos, $html_sql_quer
*
* @access private
*
- * @see PMA_displayTable()
+ * @see PMA_getTable()
*/
-function PMA_displayTableNavigation($pos_next, $pos_prev, $sql_query,
+function PMA_getTableNavigation($pos_next, $pos_prev, $sql_query,
$id_for_direction_dropdown
) {
global $db, $table, $goto;
global $num_rows, $unlim_num_rows;
global $is_innodb;
global $showtable;
+
+ $table_navigation_html = '';
// here, using htmlentities() would cause problems if the query
// contains accented characters
@@ -315,24 +315,22 @@ function PMA_displayTableNavigation($pos_next, $pos_prev, $sql_query,
*/
$is_innodb = (isset($showtable['Type']) && $showtable['Type'] == 'InnoDB');
- ?>
-
-
-
'
+ . ''
+ . '';
+
+ return $table_navigation_html;
+
+} // end of the 'PMA_getTableNavigation()' function
/**
- * Displays the headers of the results table
+ * Get the headers of the results table
*
* @param array &$is_display which elements to display
* @param array &$fields_meta the list of fields properties
@@ -537,7 +538,7 @@ function PMA_displayTableNavigation($pos_next, $pos_prev, $sql_query,
* @param string $sort_expression_nodirection sort expression without direction
* @param string $sort_direction sort direction
*
- * @return boolean $clause_is_unique
+ * @return string html content
*
* @global string $db the database name
* @global string $table the table name
@@ -550,9 +551,9 @@ function PMA_displayTableNavigation($pos_next, $pos_prev, $sql_query,
*
* @access private
*
- * @see PMA_displayTable()
+ * @see PMA_getTable()
*/
-function PMA_displayTableHeaders(&$is_display, &$fields_meta, $fields_cnt = 0,
+function PMA_getTableHeaders(&$is_display, &$fields_meta, $fields_cnt = 0,
$analyzed_sql = '', $sort_expression = '', $sort_expression_nodirection = '',
$sort_direction = ''
) {
@@ -1350,11 +1351,8 @@ function PMA_displayTableHeaders(&$is_display, &$fields_meta, $fields_cnt = 0,
}
- // render all HTML content related to table headers
- echo $table_headers_html;
-
- return true;
-} // end of the 'PMA_displayTableHeaders()' function
+ return $table_headers_html;
+} // end of the 'PMA_getTableHeaders()' function
/**
@@ -1404,10 +1402,9 @@ function PMA_buildNullDisplay($class, $condition_field, $meta, $align = '')
*/
function PMA_buildEmptyDisplay($class, $condition_field, $meta, $align = '')
{
- $nowrap = ' nowrap';
return '
';
}
@@ -1455,7 +1452,7 @@ function PMA_addClass($class, $condition_field, $meta, $nowrap,
. $enum_class . $set_class . $bit_class . $mime_type_class;
}
/**
- * Displays the body of the results table
+ * Prepare the body of the results table
*
* @param integer &$dt_result the link id associated to the query
* which results have to be displayed
@@ -1463,7 +1460,7 @@ function PMA_addClass($class, $condition_field, $meta, $nowrap,
* @param array $map the list of relations
* @param array $analyzed_sql the analyzed query
*
- * @return boolean always true
+ * @return array ($table_body_html, $clause_is_unique)
*
* @global string $db the database name
* @global string $table the table name
@@ -1479,9 +1476,9 @@ function PMA_addClass($class, $condition_field, $meta, $nowrap,
*
* @access private
*
- * @see PMA_displayTable()
+ * @see PMA_getTable()
*/
-function PMA_displayTableBody(&$dt_result, &$is_display, $map, $analyzed_sql)
+function PMA_getTableBodyParams(&$dt_result, &$is_display, $map, $analyzed_sql)
{
global $db, $table, $goto;
global $sql_query, $fields_meta, $fields_cnt;
@@ -1704,7 +1701,7 @@ function PMA_displayTableBody(&$dt_result, &$is_display, $map, $analyzed_sql)
if (! isset($js_conf)) {
$js_conf = '';
}
- $table_body_html .= PMA_generateCheckboxAndLinks(
+ $table_body_html .= PMA_getCheckboxAndLinks(
'left', $del_url, $is_display,
$row_no, $where_clause, $where_clause_html, $condition_array,
$del_query, 'l', $edit_url, $copy_url, $edit_anchor_class,
@@ -1717,7 +1714,7 @@ function PMA_displayTableBody(&$dt_result, &$is_display, $map, $analyzed_sql)
if (! isset($js_conf)) {
$js_conf = '';
}
- $table_body_html .= PMA_generateCheckboxAndLinks(
+ $table_body_html .= PMA_getCheckboxAndLinks(
'none', $del_url, $is_display,
$row_no, $where_clause, $where_clause_html, $condition_array,
$del_query, 'l', $edit_url, $copy_url, $edit_anchor_class,
@@ -1853,7 +1850,7 @@ function PMA_displayTableBody(&$dt_result, &$is_display, $map, $analyzed_sql)
$where_comparison = ' = ' . $row[$i];
$vertical_display['data'][$row_no][$i] = '
0
@@ -2269,7 +2263,7 @@ function PMA_displayVerticalTable()
$vertical_table_html .= '' . "\n";
} // end if
- // Displays "edit" link at top if required
+ // Prepares "edit" link at top if required
if (($GLOBALS['cfg']['RowActionLinks'] == 'left'
|| $GLOBALS['cfg']['RowActionLinks'] == 'both')
&& is_array($vertical_display['edit'])
@@ -2286,7 +2280,7 @@ function PMA_displayVerticalTable()
$vertical_table_html .= '' . "\n";
} // end if
- // Displays "copy" link at top if required
+ // Prepares "copy" link at top if required
if (($GLOBALS['cfg']['RowActionLinks'] == 'left'
|| $GLOBALS['cfg']['RowActionLinks'] == 'both')
&& is_array($vertical_display['copy'])
@@ -2303,7 +2297,7 @@ function PMA_displayVerticalTable()
$vertical_table_html .= '' . "\n";
} // end if
- // Displays "delete" link at top if required
+ // Prepares "delete" link at top if required
if (($GLOBALS['cfg']['RowActionLinks'] == 'left'
|| $GLOBALS['cfg']['RowActionLinks'] == 'both')
&& is_array($vertical_display['delete'])
@@ -2332,7 +2326,7 @@ function PMA_displayVerticalTable()
$col_visib = false;
}
- // Displays data
+ // Prepares data
foreach ($vertical_display['desc'] AS $j => $val) {
// assign appropriate key with current column order
$key = $col_order ? $col_order[$j] : $j;
@@ -2357,7 +2351,7 @@ function PMA_displayVerticalTable()
$vertical_table_html .= '' . "\n";
} // end while
- // Displays "multi row delete" link at bottom if required
+ // Prepares "multi row delete" link at bottom if required
if (($GLOBALS['cfg']['RowActionLinks'] == 'right'
|| $GLOBALS['cfg']['RowActionLinks'] == 'both')
&& is_array($vertical_display['row_delete'])
@@ -2384,7 +2378,7 @@ function PMA_displayVerticalTable()
$vertical_table_html .= '' . "\n";
} // end if
- // Displays "edit" link at bottom if required
+ // Prepares "edit" link at bottom if required
if (($GLOBALS['cfg']['RowActionLinks'] == 'right'
|| $GLOBALS['cfg']['RowActionLinks'] == 'both')
&& is_array($vertical_display['edit'])
@@ -2401,7 +2395,7 @@ function PMA_displayVerticalTable()
$vertical_table_html .= '' . "\n";
} // end if
- // Displays "copy" link at bottom if required
+ // Prepares "copy" link at bottom if required
if (($GLOBALS['cfg']['RowActionLinks'] == 'right'
|| $GLOBALS['cfg']['RowActionLinks'] == 'both')
&& is_array($vertical_display['copy'])
@@ -2418,7 +2412,7 @@ function PMA_displayVerticalTable()
$vertical_table_html .= '' . "\n";
} // end if
- // Displays "delete" link at bottom if required
+ // Prepares "delete" link at bottom if required
if (($GLOBALS['cfg']['RowActionLinks'] == 'right'
|| $GLOBALS['cfg']['RowActionLinks'] == 'both')
&& is_array($vertical_display['delete'])
@@ -2436,12 +2430,9 @@ function PMA_displayVerticalTable()
} // end while
$vertical_table_html .= '' . "\n";
}
-
- // render HTML content of verticle table
- echo $vertical_table_html;
- return true;
-} // end of the 'PMA_displayVerticalTable' function
+ return $vertical_table_html;
+} // end of the 'PMA_getVerticalTable' function
/**
* Checks the posted options for viewing query resutls
@@ -2454,16 +2445,16 @@ function PMA_displayVerticalTable()
*
* @return void
*/
-function PMA_displayTable_checkConfigParams()
+function PMA_setConfigParamsForDisplayTable()
{
$sql_md5 = md5($GLOBALS['sql_query']);
$_SESSION['tmp_user_values']['query'][$sql_md5]['sql'] = $GLOBALS['sql_query'];
$valid_disp_dir = PMA_isValid(
- $_REQUEST['disp_direction'],
- array('horizontal', 'vertical', 'horizontalflipped')
- );
+ $_REQUEST['disp_direction'],
+ array('horizontal', 'vertical', 'horizontalflipped')
+ );
if ($valid_disp_dir) {
$_SESSION['tmp_user_values']['query'][$sql_md5]['disp_direction']
= $_REQUEST['disp_direction'];
@@ -2625,13 +2616,15 @@ function PMA_displayTable_checkConfigParams()
}
/**
- * Displays a table of results returned by a SQL query.
+ * Prepare a table of results returned by a SQL query.
* This function is called by the "sql.php" script.
*
* @param integer &$dt_result the link id associated to the query
* which results have to be displayed
* @param array &$the_disp_mode the display mode
* @param array $analyzed_sql the analyzed query
+ *
+ * @return sting Generated HTML content for resulted table
*
* @global string $db the database name
* @global string $table the table name
@@ -2653,22 +2646,24 @@ function PMA_displayTable_checkConfigParams()
*
* @access private
*
- * @see PMA_showMessage(), PMA_setDisplayMode(),
- * PMA_displayTableNavigation(), PMA_displayTableHeaders(),
- * PMA_displayTableBody(), PMA_displayResultsOperations()
+ * @see PMA_getMessage(), PMA_setDisplayMode(),
+ * PMA_getTableNavigation(), PMA_getTableHeaders(),
+ * PMA_getTableBodyParams(), PMA_getResultsOperations()
*
* @return void
*/
-function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
+function PMA_getTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
{
global $db, $table, $goto;
global $sql_query, $num_rows, $unlim_num_rows, $fields_meta, $fields_cnt;
global $vertical_display, $highlight_columns;
global $cfgRelation;
global $showtable;
+
+ $table_html = '';
// why was this called here? (already called from sql.php)
- //PMA_displayTable_checkConfigParams();
+ //PMA_setConfigParamsForDisplayTable();
/**
* @todo move this to a central place
@@ -2685,10 +2680,10 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
// "j u s t b r o w s i n g"
$pre_count = '~';
$after_count = PMA_showHint(
- PMA_sanitize(
- __('May be approximate. See [a@./Documentation.html#faq3_11@Documentation]FAQ 3.11[/a]')
- )
- );
+ PMA_sanitize(
+ __('May be approximate. See [a@./Documentation.html#faq3_11@Documentation]FAQ 3.11[/a]')
+ )
+ );
} else {
$pre_count = '';
$after_count = '';
@@ -2723,8 +2718,8 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
// even if there are many table references
if (! empty($analyzed_sql[0]['order_by_clause'])) {
$sort_expression = trim(
- str_replace(' ', ' ', $analyzed_sql[0]['order_by_clause'])
- );
+ str_replace(' ', ' ', $analyzed_sql[0]['order_by_clause'])
+ );
/**
* Get rid of ASC|DESC
*/
@@ -2769,33 +2764,33 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
// check for non printable sorted row data
$meta = $fields_meta[$sorted_column_index];
if (stristr($meta->type, 'BLOB') || $meta->type == 'geometry') {
- $column_for_first_row = PMA_handle_non_printable_contents(
- $meta->type, $row[$sorted_column_index], $transform_function,
- $transform_options, $default_function, $meta, null
- );
+ $column_for_first_row = PMA_handleNonPrintableContents(
+ $meta->type, $row[$sorted_column_index], $transform_function,
+ $transform_options, $default_function, $meta, null
+ );
} else {
$column_for_first_row = $row[$sorted_column_index];
}
$column_for_first_row = strtoupper(
- substr($column_for_first_row, 0, $GLOBALS['cfg']['LimitChars'])
- );
+ substr($column_for_first_row, 0, $GLOBALS['cfg']['LimitChars'])
+ );
// fetch last row of the result set
PMA_DBI_data_seek($dt_result, $num_rows - 1);
$row = PMA_DBI_fetch_row($dt_result);
// check for non printable sorted row data
$meta = $fields_meta[$sorted_column_index];
if (stristr($meta->type, 'BLOB') || $meta->type == 'geometry') {
- $column_for_last_row = PMA_handle_non_printable_contents(
- $meta->type, $row[$sorted_column_index], $transform_function,
- $transform_options, $default_function, $meta, null
- );
+ $column_for_last_row = PMA_handleNonPrintableContents(
+ $meta->type, $row[$sorted_column_index], $transform_function,
+ $transform_options, $default_function, $meta, null
+ );
} else {
$column_for_last_row = $row[$sorted_column_index];
}
$column_for_last_row = strtoupper(
- substr($column_for_last_row, 0, $GLOBALS['cfg']['LimitChars'])
- );
- // reset to first row for the loop in PMA_displayTableBody()
+ substr($column_for_last_row, 0, $GLOBALS['cfg']['LimitChars'])
+ );
+ // reset to first row for the loop in PMA_getTableBodyParams()
PMA_DBI_data_seek($dt_result, 0);
// we could also use here $sort_expression_nodirection
$sorted_column_message = ' [' . htmlspecialchars($sort_column)
@@ -2807,9 +2802,9 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
unset($sorted_column_index, $sort_table, $sort_column);
}
- // 2. ----- Displays the top of the page -----
+ // 2. ----- Prepare to display the top of the page -----
- // 2.1 Displays a messages with position informations
+ // 2.1 Prepares a messages with position informations
if ($is_display['nav_bar'] == '1' && isset($pos_next)) {
if (isset($unlim_num_rows) && $unlim_num_rows != $total) {
$selectstring = ', ' . $unlim_num_rows . ' ' . __('in query');
@@ -2838,8 +2833,8 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
&& $total == $GLOBALS['cfg']['MaxExactCountViews']
) {
$message = PMA_Message::notice(
- __('This view has at least this number of rows. Please refer to %sdocumentation%s.')
- );
+ __('This view has at least this number of rows. Please refer to %sdocumentation%s.')
+ );
$message->addParam('[a@./Documentation.html#cfg_MaxExactCount@_blank]');
$message->addParam('[/a]');
$message_view_warning = PMA_showHint($message);
@@ -2873,16 +2868,16 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
$message->addMessage($sorted_column_message, '');
}
- PMA_showMessage($message, $sql_query, 'success');
+ $table_html .= PMA_getMessage($message, $sql_query, 'success');
} elseif (! isset($GLOBALS['printview']) || $GLOBALS['printview'] != '1') {
- PMA_showMessage(
- __('Your SQL query has been executed successfully'),
- $sql_query, 'success'
- );
+ $table_html .= PMA_getMessage(
+ __('Your SQL query has been executed successfully'),
+ $sql_query, 'success'
+ );
}
- // 2.3 Displays the navigation bars
+ // 2.3 Prepare the navigation bars
if (! strlen($table)) {
if (isset($analyzed_sql[0]['query_type'])
&& $analyzed_sql[0]['query_type'] == 'SELECT'
@@ -2897,12 +2892,12 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
}
if ($is_display['nav_bar'] == '1' && empty($analyzed_sql[0]['limit_clause'])) {
- PMA_displayTableNavigation(
- $pos_next, $pos_prev, $sql_query, 'top_direction_dropdown'
- );
- echo "\n";
+ $table_html .= PMA_getTableNavigation(
+ $pos_next, $pos_prev, $sql_query, 'top_direction_dropdown'
+ )
+ . "\n";
} elseif (! isset($GLOBALS['printview']) || $GLOBALS['printview'] != '1') {
- echo "\n" . '
' . "\n";
+ $table_html .= "\n" . '
' . "\n";
}
// 2b ----- Get field references from Database -----
@@ -2936,40 +2931,42 @@ function PMA_displayTable(&$dt_result, &$the_disp_mode, $analyzed_sql)
if ($exist_rel) {
foreach ($exist_rel as $master_field => $rel) {
$display_field = PMA_getDisplayField(
- $rel['foreign_db'], $rel['foreign_table']
- );
+ $rel['foreign_db'], $rel['foreign_table']
+ );
$map[$master_field] = array(
- $rel['foreign_table'],
- $rel['foreign_field'],
- $display_field,
- $rel['foreign_db']
- );
+ $rel['foreign_table'],
+ $rel['foreign_field'],
+ $display_field,
+ $rel['foreign_db']
+ );
} // end while
} // end if
} // end if
// end 2b
- // 3. ----- Displays the results table -----
- PMA_displayTableHeaders(
- $is_display, $fields_meta, $fields_cnt, $analyzed_sql,
- $sort_expression, $sort_expression_nodirection, $sort_direction
- );
- $url_query = '';
- echo '
diff --git a/libraries/common.lib.php b/libraries/common.lib.php
index 556fc1787d..4ae968ad8a 100644
--- a/libraries/common.lib.php
+++ b/libraries/common.lib.php
@@ -965,7 +965,7 @@ if (typeof(window.parent) != 'undefined'
}
/**
- * displays the message and the query
+ * Prepare the message and the query
* usually the message is the result of the query executed
*
* @param string $message the message to display
@@ -977,7 +977,7 @@ if (typeof(window.parent) != 'undefined'
*
* @access public
*/
-function PMA_showMessage(
+function PMA_getMessage(
$message,
$sql_query = null,
$type = 'notice',
@@ -1337,7 +1337,7 @@ function PMA_showMessage(
return $retval;
-} // end of the 'PMA_showMessage()' function
+} // end of the 'PMA_getMessage()' function
/**
* Verifies if current MySQL server supports profiling